package net.wanji.web.task;

import com.alibaba.fastjson.JSON;
import lombok.extern.slf4j.Slf4j;
import net.wanji.common.dto.SystemServiceStatusDTO;
import net.wanji.common.utils.tool.SocketUtil;
import net.wanji.common.utils.tool.StringUtils;
import net.wanji.web.common.constant.Constant;
import net.wanji.web.common.util.date.DateStyle;
import net.wanji.web.websocket.WebSocketServer;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import java.time.LocalTime;
import java.time.format.DateTimeFormatter;
import java.util.ArrayList;
import java.util.Comparator;
import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;

/**
 * @author duanruiming
 * @date 2023/03/21 10:42
 */
@Component
@Slf4j
public class SystemServiceStatusTask {

    public static final List<SystemServiceStatusDTO> sysList = new ArrayList<SystemServiceStatusDTO>();

    static {
        sysList.add(new SystemServiceStatusDTO("MYSQL", "10.102.1.182", 3306, 30000, 0, null, null));
        sysList.add(new SystemServiceStatusDTO("UTC", "10.102.1.182", 32000, 30000, 0, null, null));
        sysList.add(new SystemServiceStatusDTO("海康", "10.102.1.183", 80, 30000, 0, null, null));
    }

    @Scheduled(fixedRate = 1 * 60 * 1000)
    public void telnetStatus() throws Exception {

        for (SystemServiceStatusDTO dto : sysList) {
            String ip = dto.getIp();
            int port = dto.getPort();
            int timeout = dto.getTimeout();
            int lastStatus = dto.getStatus();
            int currentStatus = SocketUtil.telnet(ip, port, timeout) == true ? 0 : 1;
            if (currentStatus != lastStatus) {
                dto.setStatus(currentStatus);
            }
            if (StringUtils.isBlank(dto.getStartTime())) {
                LocalTime now = LocalTime.now();
                String format = now.format(DateTimeFormatter.ofPattern(DateStyle.HH_MM_SS.getValue()));
                dto.setStartTime(format);
                dto.setStartDate(new Date());
            }
        }
        List<SystemServiceStatusDTO> sort = sysList.stream().sorted(Comparator.comparing(SystemServiceStatusDTO::getStartDate)).collect(Collectors.toList());
        WebSocketServer.sendInfo2All(JSON.toJSONString(sort), Constant.WEBSOCKET_TOPIC_SYS_SERVICE_STATUS);
    }

}
